[PATCH 078/117] Staging: hv: storvsc: Rename get_stor_device()

From: K. Y. Srinivasan
Date: Fri Jul 15 2011 - 13:41:22 EST


In preparation for cleaning up how we manage reference counts on the stor
device, clearly distinguish why we are attempting to acquire a reference.

Signed-off-by: K. Y. Srinivasan <kys@xxxxxxxxxxxxx>
Signed-off-by: Haiyang Zhang <haiyangz@xxxxxxxxxxxxx>
---
drivers/staging/hv/hyperv_storage.h | 3 ++-
drivers/staging/hv/storvsc.c | 8 ++++----
drivers/staging/hv/storvsc_drv.c | 2 +-
3 files changed, 7 insertions(+), 6 deletions(-)

diff --git a/drivers/staging/hv/hyperv_storage.h b/drivers/staging/hv/hyperv_storage.h
index a01f9a0..a224413 100644
--- a/drivers/staging/hv/hyperv_storage.h
+++ b/drivers/staging/hv/hyperv_storage.h
@@ -288,7 +288,8 @@ struct storvsc_device {


/* Get the stordevice object iff exists and its refcount > 1 */
-static inline struct storvsc_device *get_stor_device(struct hv_device *device)
+static inline struct storvsc_device *get_out_stor_device(
+ struct hv_device *device)
{
struct storvsc_device *stor_device;

diff --git a/drivers/staging/hv/storvsc_drv.c b/drivers/staging/hv/storvsc_drv.c
index bc71024..0f2fc2f 100644
--- a/drivers/staging/hv/storvsc_drv.c
+++ b/drivers/staging/hv/storvsc_drv.c
@@ -346,7 +346,7 @@ static int storvsc_host_reset(struct hv_device *device)
int ret, t;


- stor_device = get_stor_device(device);
+ stor_device = get_out_stor_device(device);
if (!stor_device)
return -ENODEV;

diff --git a/drivers/staging/hv/storvsc.c b/drivers/staging/hv/storvsc.c
index 89708b1..313a3f8 100644
--- a/drivers/staging/hv/storvsc.c
+++ b/drivers/staging/hv/storvsc.c
@@ -41,7 +41,7 @@ static inline struct storvsc_device *alloc_stor_device(struct hv_device *device)
return NULL;

/* Set to 2 to allow both inbound and outbound traffics */
/* (ie get_stor_device() and get_in_stor_device()) to proceed. */
atomic_cmpxchg(&stor_device->ref_count, 0, 2);

init_waitqueue_head(&stor_device->waiting_to_drain);
@@ -67,7 +67,7 @@ static inline struct storvsc_device *get_in_stor_device(
return stor_device;
}

/* Drop ref count to 1 to effectively disable get_stor_device() */
static inline struct storvsc_device *release_stor_device(
struct hv_device *device)
{
@@ -105,7 +105,7 @@ static int storvsc_channel_init(struct hv_device *device)
struct vstor_packet *vstor_packet;
int ret, t;

- stor_device = get_stor_device(device);
+ stor_device = get_out_stor_device(device);
if (!stor_device)
return -ENODEV;

@@ -427,7 +427,7 @@ int storvsc_do_io(struct hv_device *device,
int ret = 0;

vstor_packet = &request->vstor_packet;
- stor_device = get_stor_device(device);
+ stor_device = get_out_stor_device(device);

if (!stor_device)
return -ENODEV;
@@ -41,7 +41,7 @@ static inline struct storvsc_device *alloc_stor_device(struct hv_device *device)

/* Set to 2 to allow both inbound and outbound traffics */
- /* (ie get_stor_device() and get_in_stor_device()) to proceed. */
+ /* (ie get_out_stor_device() and get_in_stor_device()) to proceed. */
atomic_cmpxchg(&stor_device->ref_count, 0, 2);

@@ -67,7 +67,7 @@ static inline struct storvsc_device *get_in_stor_device(
}

-/* Drop ref count to 1 to effectively disable get_stor_device() */
+/* Drop ref count to 1 to effectively disable get_out_stor_device() */
static inline struct storvsc_device *release_stor_device(
struct hv_device *device)
--
1.7.4.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/